﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Reflection;
using System.Text;
using System.Threading.Tasks;

namespace MontoyaTech.MySqlPlus
{
    /// <summary>
    /// The outline of a MySqlRow attribute that is used to specify
    /// information about a MySqlRow.
    /// </summary>
    [AttributeUsage(AttributeTargets.Class | AttributeTargets.Struct, AllowMultiple = false, Inherited = true)]
    public class MySqlRow : Attribute
    {
        /// <summary>
        /// The name of the table.
        /// </summary>
        public string Name;

        /// <summary>
        /// Creates a new default MySqlRow.
        /// </summary>
        public MySqlRow() { }

        /// <summary>
        /// Creates a new MySqlRow with a name.
        /// </summary>
        /// <param name="name"></param>
        public MySqlRow(string name)
        {
            this.Name = name;
        }

        /// <summary>
        /// Attempts to return the table name of a Type that
        /// has a MySqlRow attribute.
        /// </summary>
        /// <typeparam name="T"></typeparam>
        /// <returns></returns>
        public static string GetName<T>()
        {
            var row = typeof(T).GetCustomAttribute<MySqlRow>();

            if (row == null)
                throw new InvalidOperationException("Type is not a MySqlRow.");

            return row.Name;
        }
    }
}
